================
autoextract-poet
================

.. image:: https://img.shields.io/pypi/v/autoextract-poet.svg
   :target: https://pypi.python.org/pypi/autoextract-poet
   :alt: PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/autoextract-poet.svg
   :target: https://pypi.python.org/pypi/autoextract-poet
   :alt: Supported Python Versions

.. image:: https://github.com/scrapinghub/autoextract-poet/workflows/tox/badge.svg
   :target: https://github.com/scrapinghub/autoextract-poet/actions
   :alt: Build Status

.. image:: https://codecov.io/github/scrapinghub/autoextract-poet/coverage.svg?branch=master
   :target: https://codecov.io/gh/scrapinghub/autoextract-poet
   :alt: Coverage report

.. warning::
    Current status is "experimental".

``autoextract-poet`` implements `web-poet`_'s Page Objects for AutoExtract API.

License is BSD 3-clause.

* Source code: https://github.com/scrapinghub/autoextract-poet
* Issue tracker: https://github.com/scrapinghub/autoextract-poet/issues

.. _`web-poet`: https://github.com/scrapinghub/web-poet
